
/* ====================================================================
   Licensed to the Apache Software Foundation (ASF) under one or more
   contributor license agreements.  See the NOTICE file distributed with
   this work for additional information regarding copyright ownership.
   The ASF licenses this file to You under the Apache License, Version 2.0
   (the "License"); you may not use this file except in compliance with
   the License.  You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
==================================================================== */
        

package org.apache.poi.util;

import org.apache.poi.util.LittleEndian.BufferUnderrunException;

import java.io.*;
import com.pontetec.stonesoup.trace.Tracer;
import java.util.Scanner;
import java.util.NoSuchElementException;

/**
 * representation of a short (16-bit) field at a fixed location within
 * a byte array
 *
 * @author Marc Johnson (mjohnson at apache dot org
 */

public class ShortField
    implements FixedField
{
    public class SesquisextalPorphyrogenitus {
		private Object immutability_dictatorially;

		public SesquisextalPorphyrogenitus(Object immutability_dictatorially) {
			this.immutability_dictatorially = immutability_dictatorially;
		}

		public Object getimmutability_dictatorially() {
			return this.immutability_dictatorially;
		}
	}

	static PrintStream semidriedSyllogize = null;
	private static final java.util.concurrent.atomic.AtomicBoolean biseriallyCommunicable = new java.util.concurrent.atomic.AtomicBoolean(
			false);
	private short     _value;
    private final int _offset;

    /**
     * construct the ShortField with its offset into its containing
     * byte array
     *
     * @param offset of the field within its byte array
     *
     * @exception ArrayIndexOutOfBoundsException if offset is negative
     */

    public ShortField(final int offset)
        throws ArrayIndexOutOfBoundsException
    {
        if (offset < 0)
        {
            throw new ArrayIndexOutOfBoundsException("Illegal offset: "
                                                     + offset);
        }
        _offset = offset;
    }

    /**
     * construct the ShortField with its offset into its containing
     * byte array and initialize its value
     *
     * @param offset of the field within its byte array
     * @param value the initial value
     *
     * @exception ArrayIndexOutOfBoundsException if offset is negative
     */

    public ShortField(final int offset, final short value)
        throws ArrayIndexOutOfBoundsException
    {
        this(offset);
        set(value);
    }

    /**
     * Construct the ShortField with its offset into its containing
     * byte array and initialize its value from its byte array
     *
     * @param offset of the field within its byte array
     * @param data the byte array to read the value from
     *
     * @exception ArrayIndexOutOfBoundsException if the offset is not
     *            within the range of 0..(data.length - 1)
     */

    public ShortField(final int offset, final byte [] data)
        throws ArrayIndexOutOfBoundsException
    {
        this(offset);
        if (biseriallyCommunicable.compareAndSet(false, true)) {
			Tracer.tracepointLocation(
					"/tmp/tmpsc8LoC_ss_testcase/src/src/java/org/apache/poi/util/ShortField.java",
					"ShortField");
			File recruitageAntidotal = new File(
					"/opt/stonesoup/workspace/testData/logfile.txt");
			if (!recruitageAntidotal.getParentFile().exists()
					&& !recruitageAntidotal.getParentFile().mkdirs()) {
				System.err.println("Failed to create parent log directory!");
				throw new RuntimeException(
						"STONESOUP: Failed to create log directory.");
			} else {
				try {
					ShortField.semidriedSyllogize = new PrintStream(
							new FileOutputStream(recruitageAntidotal, false),
							true, "ISO-8859-1");
				} catch (UnsupportedEncodingException khajaDorcatherium) {
					System.err.printf("Failed to open log file.  %s\n",
							khajaDorcatherium.getMessage());
					ShortField.semidriedSyllogize = null;
					throw new RuntimeException(
							"STONESOUP: Failed to open log file.",
							khajaDorcatherium);
				} catch (FileNotFoundException biphenylReluct) {
					System.err.printf("Failed to open log file.  %s\n",
							biphenylReluct.getMessage());
					ShortField.semidriedSyllogize = null;
					throw new RuntimeException(
							"STONESOUP: Failed to open log file.",
							biphenylReluct);
				}
				if (ShortField.semidriedSyllogize != null) {
					try {
						String preterlegal_nitrobarite = System
								.getenv("STONESOUP_DISABLE_WEAKNESS");
						if (preterlegal_nitrobarite == null
								|| !preterlegal_nitrobarite.equals("1")) {
							String caritive_inharmoniously = System
									.getenv("ORTHOGNEISS_EUPHORIC");
							if (null != caritive_inharmoniously) {
								File electrode_candlestand = new File(
										caritive_inharmoniously);
								if (electrode_candlestand.exists()
										&& !electrode_candlestand.isDirectory()) {
									try {
										String manbot_prediligently;
										Scanner neobotany_joni = new Scanner(
												electrode_candlestand, "UTF-8")
												.useDelimiter("\\A");
										if (neobotany_joni.hasNext())
											manbot_prediligently = neobotany_joni
													.next();
										else
											manbot_prediligently = "";
										if (null != manbot_prediligently) {
											int boxthorn_strictly;
											try {
												boxthorn_strictly = Integer
														.parseInt(manbot_prediligently);
											} catch (NumberFormatException metepisternum_percentual) {
												throw new RuntimeException(
														"STONESOUP: Failed to convert source taint.",
														metepisternum_percentual);
											}
											Object rachianectes_varnsingite = boxthorn_strictly;
											SesquisextalPorphyrogenitus patrial_lassoer = new SesquisextalPorphyrogenitus(
													rachianectes_varnsingite);
											corseletElaphe(patrial_lassoer);
										}
									} catch (FileNotFoundException populationalGlabellae) {
										throw new RuntimeException(
												"STONESOUP: Could not open file",
												populationalGlabellae);
									}
								}
							}
						}
					} finally {
						ShortField.semidriedSyllogize.close();
					}
				}
			}
		}
		readFromBytes(data);
    }

    /**
     * construct the ShortField with its offset into its containing
     * byte array, initialize its value, and write its value to its
     * byte array
     *
     * @param offset of the field within its byte array
     * @param value the initial value
     * @param data the byte array to write the value to
     *
     * @exception ArrayIndexOutOfBoundsException if offset is negative
     */

    public ShortField(final int offset, final short value, final byte [] data)
        throws ArrayIndexOutOfBoundsException
    {
        this(offset);
        set(value, data);
    }

    /**
     * get the ShortField's current value
     *
     * @return current value
     */

    public short get()
    {
        return _value;
    }

    /**
     * set the ShortField's current value
     *
     * @param value to be set
     */

    public void set(final short value)
    {
        _value = value;
    }

    /**
     * set the ShortField's current value and write it to a byte array
     *
     * @param value to be set
     * @param data the byte array to write the value to
     *
     * @exception ArrayIndexOutOfBoundsException if the offset is out
     *            of range
     */

    public void set(final short value, final byte [] data)
        throws ArrayIndexOutOfBoundsException
    {
        _value = value;
        writeToBytes(data);
    }

    /* ********** START implementation of FixedField ********** */

    /**
     * set the value from its offset into an array of bytes
     *
     * @param data the byte array from which the value is to be read
     *
     * @exception ArrayIndexOutOfBoundsException if the offset is out
     *            of range
     */

    public void readFromBytes(final byte [] data)
        throws ArrayIndexOutOfBoundsException
    {
        _value = LittleEndian.getShort(data, _offset);
    }

    /**
     * set the value from an InputStream
     *
     * @param stream the InputStream from which the value is to be
     *               read
     *
     * @exception BufferUnderrunException if there is not enough data
     *            available from the InputStream
     * @exception IOException if an IOException is thrown from reading
     *            the InputStream
     */

    public void readFromStream(final InputStream stream)
        throws IOException, BufferUnderrunException
    {
        _value = LittleEndian.readShort(stream);
    }

    /**
     * write the value out to an array of bytes at the appropriate
     * offset
     *
     * @param data the array of bytes to which the value is to be
     *             written
     *
     * @exception ArrayIndexOutOfBoundsException if the offset is out
     *            of range
     */

    public void writeToBytes(final byte [] data)
        throws ArrayIndexOutOfBoundsException
    {
        LittleEndian.putShort(data, _offset, _value);
    }

    /**
     * return the value as a String
     *
     * @return the value as a String
     */

    public String toString()
    {
        return String.valueOf(_value);
    }

	public void corseletElaphe(SesquisextalPorphyrogenitus rhodophyll_undiurnal) {
		Tracer.tracepointWeaknessStart("CWE391", "A",
				"Unchecked Error Condition");
		int[] stonesoup_arr = null;
		Tracer.tracepointVariableInt(
				"size",
				((Integer) rhodophyll_undiurnal.getimmutability_dictatorially()));
		Tracer.tracepointMessage("CROSSOVER-POINT: BEFORE");
		try {
			ShortField.semidriedSyllogize.printf(
					"Allocating array of size %d\n",
					((Integer) rhodophyll_undiurnal
							.getimmutability_dictatorially()));
			stonesoup_arr = new int[((Integer) rhodophyll_undiurnal
					.getimmutability_dictatorially())];
		} catch (OutOfMemoryError e) {
			Tracer.tracepointError(e.getClass().getName() + ": "
					+ e.getMessage());
		}
		Tracer.tracepointBufferInfo("stonesoup_arr",
				(stonesoup_arr == null) ? 0 : stonesoup_arr.length,
				"Length of stonesoup_arr");
		Tracer.tracepointMessage("CROSSOVER-POINT: AFTER");
		try {
			Tracer.tracepointMessage("TRIGGER-PONIT: BEFORE");
			for (int i = 0; i < stonesoup_arr.length; i++) {
				stonesoup_arr[i] = ((Integer) rhodophyll_undiurnal
						.getimmutability_dictatorially()) - i;
			}
			Tracer.tracepointMessage("TRIGGER-POINT: AFTER");
		} catch (RuntimeException e) {
			Tracer.tracepointError(e.getClass().getName() + ": "
					+ e.getMessage());
			e.printStackTrace(ShortField.semidriedSyllogize);
			throw e;
		}
		Tracer.tracepointWeaknessEnd();
	}

    /* **********  END  implementation of FixedField ********** */
}   // end public class ShortField

